summaryrefslogtreecommitdiffstats
path: root/make/config/jogl/egl-CustomCCode.c
diff options
context:
space:
mode:
authorSven Gothel <[email protected]>2015-01-23 00:48:16 +0100
committerSven Gothel <[email protected]>2015-01-23 00:48:16 +0100
commitd0676451343e826e49d9c5732320f080d4c11c8d (patch)
tree1b756b7063d7f0ed512d80ef0a7cbd28f9d6ab76 /make/config/jogl/egl-CustomCCode.c
parent6253fe0f8e4191018a9d2b7bb7c1d7ab2392a6f4 (diff)
Bug 1096 - Expose EGL to public: com.jogamp.opengl.egl.EGL ; EGLDrawableFactory: Validate static EGL func-ptr, probe EGL/ES2 first
- Move EGL to public package jogamp.opengl.egl.EGL -> com.jogamp.opengl.egl.EGL - EGLDrawableFactory - Validate static EGL func-ptr against EGL/ES2, ignoring EGL/[ES|GL] collisions w/ diff. native EGL implementations due to static EGL usage. - Probe EGL/ES2 first
Diffstat (limited to 'make/config/jogl/egl-CustomCCode.c')
-rw-r--r--make/config/jogl/egl-CustomCCode.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/make/config/jogl/egl-CustomCCode.c b/make/config/jogl/egl-CustomCCode.c
index 0163c6742..5dd34232c 100644
--- a/make/config/jogl/egl-CustomCCode.c
+++ b/make/config/jogl/egl-CustomCCode.c
@@ -4,10 +4,10 @@
#include <EGL/egl.h>
/* Java->C glue code:
* Java package: jogamp.opengl.egl.EGL
* Java method: void eglGetConfigAttributes(long dpy, long config, IntBuffer attributes, IntBuffer values)
*/
-Java_jogamp_opengl_egl_EGL_dispatch_1eglGetConfigAttributes(JNIEnv *env, jclass _unused, jlong dpy, jlong config, jint attributeCount, jobject attributes, jint attributes_byte_offset, jobject values, jint values_byte_offset, jlong procAddress) {
+Java_com_jogamp_opengl_egl_EGL_dispatch_1eglGetConfigAttributes(JNIEnv *env, jclass _unused, jlong dpy, jlong config, jint attributeCount, jobject attributes, jint attributes_byte_offset, jobject values, jint values_byte_offset, jlong procAddress) {
typedef EGLBoolean (EGLAPIENTRY*_local_PFNEGLGETCONFIGATTRIBPROC)(EGLDisplay dpy, EGLConfig config, EGLint attribute, EGLint * value);
_local_PFNEGLGETCONFIGATTRIBPROC ptr_eglGetConfigAttrib = (_local_PFNEGLGETCONFIGATTRIBPROC) (intptr_t) procAddress;
assert(ptr_eglGetConfigAttrib != NULL);
@@ -4,10 +4,10 @@
#include <EGL/egl.h>
/* Java->C glue code:
- * Java package: jogamp.opengl.egl.EGL
+ * Java package: com.jogamp.opengl.egl.EGL
* Java method: void eglGetConfigAttributes(long dpy, long config, IntBuffer attributes, IntBuffer values)
*/